/**
 * @file button.c
 * @author Rmi Heredero (remi@heredero.ch)
 * @version 0.1
 * @date 2023-06-06
 * 
 */

#include "button.h"
#include "../../mcc_generated_files/pin_manager.h"

/**
 * @brief Initialize the button
 * 
 * @param me The object to initialize
 * @param id The id of the button
 */
void BUTTON_init(BUTTON* me, uint8_t id) {
    me->id = id;
    me->state = ST_PBINIT;

}

/**
 * @brief Initialize the hardware of the button
 * 
 * @param me The object to initialize
 */
void BUTTON_initHW(BUTTON* me) {
    switch (me->id) {
        case 1:
            INPUT1_SetDigitalInput();
            break;
        case 2:
            INPUT2_SetDigitalInput();
            break;
        case 3:
            INPUT3_SetDigitalInput();
            break;
        default:
            break;
    }
}

/**
 * @brief Check if the button is pressed
 * The function returns true if the button is pressed, false otherwise
 * 
 * @param me The object to check
 * @return true if the button is pressed
 * @return false if the button is not pressed
 */
bool BUTTON_isPressed(BUTTON* me) {
    switch (me->id) {
        case 1:
            return INPUT1_GetValue();
            break;
        case 2:
            return INPUT2_GetValue();
            break;
        case 3:
            return INPUT3_GetValue();
            break;
        default:
            return false;
            break;
    }
}